==> pyobjc_framework_quartz-11.0.tar.gz: pyobjc_framework_quartz-11.0/Modules/_quartzcore.m <==
/*
 * Manual wrappers for QuartzCore
 */
#define PY_SSIZE_T_CLEAN
#include "Python.h"
#include "pyobjc-api.h"

#if PyObjC_BUILD_RELEASE >= 1015
#import <CoreImage/CIFilterBuiltins.h>
#endif

#if PyObjC_BUILD_RELEASE >= 1013
#import <CoreImage/CoreImage.h>
#endif

#import <Quartz/Quartz.h>

#include "_CoreImage_protocols.m"
#include "_QuartzCore_protocols.m"

static PyMethodDef mod_methods[] = {{
    0,
    0,
    0,
}};

static int mod_exec_module(PyObject* m)
{
    return 0;
}

static struct PyModuleDef_Slot mod_slots[] = {
    {
        .slot = Py_mod_exec,
        .value = (void*)mod_exec_module
    },
#if PY_VERSION_HEX >= 0x030c0000
    {
        /* This extension does not use the CPython API other than initializing
         * the module, hence is safe with subinterpreters and per-interpreter
         * GILs
         */
        .slot = Py_mod_multiple_interpreters,
        .value = Py_MOD_PER_INTERPRETER_GIL_SUPPORTED,
    },
#endif
#if PY_VERSION_HEX >= 0x030d0000
    {
        /* The code in this extension should be safe to use without the GIL */
        .slot = Py_mod_gil,
        .value = Py_MOD_GIL_NOT_USED,
    },
#endif
    {  /* Sentinel */
        .slot = 0,
        .value = 0
    }
};

static struct PyModuleDef mod_module = {
    .m_base = PyModuleDef_HEAD_INIT,
    .m_name = "_quartzcore",
    .m_doc = NULL,
    .m_size = 0,
    .m_methods = mod_methods,
    .m_slots = mod_slots,
    .m_traverse = NULL,
    .m_clear = NULL,
    .m_free = NULL,
};

PyObject* PyInit__quartzcore(void);

PyObject* __attribute__((__visibility__("default"))) PyInit__quartzcore(void)
{
    return PyModuleDef_Init(&mod_module);
}

==> pyobjc_framework_quartz-12.1.tar.gz: pyobjc_framework_quartz-12.1/Modules/_quartzcore.m <==
/*
 * Manual wrappers for QuartzCore
 */
#define PY_SSIZE_T_CLEAN
#include "Python.h"
#include "pyobjc-api.h"

#if PyObjC_BUILD_RELEASE >= 1015
#import <CoreImage/CIFilterBuiltins.h>
#endif

#if PyObjC_BUILD_RELEASE >= 1013
#import <CoreImage/CoreImage.h>
#endif

#import <Quartz/Quartz.h>

#include "_CoreImage_protocols.m"
#include "_QuartzCore_protocols.m"

static PyMethodDef mod_methods[] = {{
    0,
    0,
    0,
}};

static int
mod_exec_module(PyObject* m)
{
    return 0;
}

static struct PyModuleDef_Slot mod_slots[] = {
    {.slot = Py_mod_exec, .value = (void*)mod_exec_module},
#if PY_VERSION_HEX >= 0x030c0000
    {
        /* This extension does not use the CPython API other than initializing
         * the module, hence is safe with subinterpreters and per-interpreter
         * GILs
         */
        .slot  = Py_mod_multiple_interpreters,
        .value = Py_MOD_PER_INTERPRETER_GIL_SUPPORTED,
    },
#endif
#if PY_VERSION_HEX >= 0x030d0000
    {
        /* The code in this extension should be safe to use without the GIL */
        .slot  = Py_mod_gil,
        .value = Py_MOD_GIL_NOT_USED,
    },
#endif
    {/* Sentinel */
     .slot  = 0,
     .value = 0}};

static struct PyModuleDef mod_module = {
    .m_base     = PyModuleDef_HEAD_INIT,
    .m_name     = "_quartzcore",
    .m_doc      = NULL,
    .m_size     = 0,
    .m_methods  = mod_methods,
    .m_slots    = mod_slots,
    .m_traverse = NULL,
    .m_clear    = NULL,
    .m_free     = NULL,
};

PyObject* PyInit__quartzcore(void);

PyObject* __attribute__((__visibility__("default")))
PyInit__quartzcore(void)
{
    return PyModuleDef_Init(&mod_module);
}
